<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>InfoDistanceEE</name>
    <message>
        <location filename="../InfoDistanceEE.js" line="+62"/>
        <source>Specify first entity</source>
        <translation>Určete první objekt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second entity</source>
        <translation>Určete druhý objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Distance:</source>
        <translation>Vzdálenost:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEEInit.js" line="+2"/>
        <source>Distance &amp;Entity to Entity</source>
        <translation>Vzdálenost mezi &amp;objekty</translation>
    </message>
</context>
</TS>
